'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AMP = exports.renderToString = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _server = require('react-dom/server');

var _styledComponents = require('styled-components');

var _pretty = require('pretty');

var _pretty2 = _interopRequireDefault(_pretty);

var _store = require('./store');

var _store2 = _interopRequireDefault(_store);

var _Components = require('./Components');

var _Components2 = _interopRequireDefault(_Components);

var _Head = require('./Components/Head');

var _Head2 = _interopRequireDefault(_Head);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Transform React component into HTML AMP format.
 * @returns {String} html
 * @param {Class|Object} body React component to render
 * @param {Object} options Settings
 * @property {string} options.cdnURI absolute URL to AMP CDN
 * @property {string} options.boilerplate HTML string which contains AMP boilerplate styles
 * @property {object} options.extensions Key map of references to specify an extension version
 * @property {object} options.extensions.default default version for all amp-extensions e.g '0.1'
 * @property {object} options.extensions.extension [extension-name]
 ** specify custom version for derived extension e.g: 'amp-sticky-ad': '1.0'
 */
const renderToString = exports.renderToString = (body, options = {}) => {
  (0, _store.setOptions)(options);
  const sheet = new _styledComponents.ServerStyleSheet();
  const bodyStyless = (0, _pretty2.default)((0, _server.renderToStaticMarkup)(sheet.collectStyles(body)));
  const styles = sheet.getStyleElement()[0];
  // eslint-disable-next-line no-underscore-dangle
  const css = styles ? styles.props.dangerouslySetInnerHTML.__html : '';
  const head = (0, _pretty2.default)((0, _server.renderToStaticMarkup)(_react2.default.createElement(_Head2.default, { css: css }))).replace('<style amp-boilerplate=""></style>', _store2.default.boilerplate);

  return `<!DOCTYPE html>\n<html ⚡>\n${head}\n${bodyStyless}\n</html>`;
};

exports.AMP = _Components2.default;
//# sourceMappingURL=index.js.map